package catshelter.editor;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.forms.widgets.FormToolkit;
import org.eclipse.ui.part.EditorPart;

import catshelter.CatShelterView;
import catshelter.model.Cat;
import catshelter.model.Gender;

public class CatEditor extends EditorPart {

	public static final String ID = "catshelter.editor";
	private Cat cat;

	private static final GridData FILL = new GridData(GridData.FILL_HORIZONTAL);
	
	private Button male;
	private Button female;
	private Text name;
	private Text likes;
	private Button save;
	
	public CatEditor() {
		super();
	}

	@Override
	public void doSave(IProgressMonitor monitor) {

	}

	@Override
	public void doSaveAs() {

	}

	@Override
	public void init(IEditorSite site, IEditorInput input)
			throws PartInitException {
		if (!(input instanceof CatEditorInput)) {
			throw new RuntimeException("Input not of type " + CatEditorInput.class.getName());
		}
		
		setSite(site);
		setInput(input);
		setPartName(input.getName());
		cat = (Cat) input.getAdapter(Cat.class);
	}

	@Override
	public boolean isDirty() {
		return false;
	}

	@Override
	public boolean isSaveAsAllowed() {
		return false;
	}

	@Override
	public void createPartControl(Composite parent) {
		FormToolkit tk = new FormToolkit(parent.getDisplay());
		Composite body = tk.createForm(parent).getBody();
		body.setLayoutData(new GridLayout(2, true));
		
		tk.createLabel(body, "Name:");
		name = new Text(body, SWT.BORDER);
		name.setLayoutData(FILL);
		
		tk.createLabel(body, "Likes:");
		likes = new Text(body, SWT.BORDER);
		likes.setLayoutData(FILL);
		
		tk.createLabel(body, "Gender:");
		Composite group = tk.createComposite(body);
		group.setLayout(new FillLayout(SWT.VERTICAL));
		male = tk.createButton(group, "Male", SWT.RADIO);
		female = tk.createButton(group, "Female", SWT.RADIO);
		
		setValuesToFields(cat);
		
		save = tk.createButton(group, "Save", SWT.PUSH);
		save.addSelectionListener(new SelectionListener() {
			@Override
			public void widgetSelected(SelectionEvent e) {
				saveValuesToModel(cat);

				IWorkbenchPage page = getSite().getPage();
				IViewPart view = page.findView(CatShelterView.ID);
				if (view instanceof CatShelterView) {
					((CatShelterView) view).getViewer().refresh();
				}
			}

			@Override
			public void widgetDefaultSelected(SelectionEvent e) {
			
			}
		});
	}

	private void setValuesToFields(Cat cat) {
		name.setText(cat.getName());
		likes.setText(cat.getLikes());
		switch(cat.getGender()) {
			case male : this.male.setSelection(true);
				break;
			case female : this.female.setSelection(true);
				break;
		}
	}
	
	private void saveValuesToModel(Cat cat) {
		cat.setName(name.getText());
		cat.setLikes(likes.getText());
		if (male.getSelection()) {
			cat.setGender(Gender.male);
		} else if (female.getSelection()) {
			cat.setGender(Gender.female);
		}
	}
	
	@Override
	public void setFocus() {

	}

}
